/*

Count-down and Count-up
Version 1.01

Author: Tommy_2Tall ( at ) home . se

*/

var CountingDownText	= "down";	// Inserted by the <DownOrUp> tag if CountingDown is true.
var CountingUpText	= "up";		// Inserted by the <DownOrUp> tag if CountingDown is false.

var iOneSecond		= 1000;
var iOneMinute		= 60 * iOneSecond;
var iOneHour		= 60 * iOneMinute;
var iOneDay		= 24 * iOneHour;
var iOneWeek		= 7 * iOneDay;

function CountDownOrUp( YYYY , MM, DD , Hours, Minutes, Seconds, OutputFormat) {

	YYYY	= parseInt( YYYY ,10);
	MM	= parseInt( MM , 10)-1;
	DD	= parseInt( DD , 10);
	Hours	= parseInt( Hours , 10);
	Minutes	= parseInt( Minutes , 10);
	Seconds	= parseInt( Seconds , 10);

	if (isNaN( YYYY ))					return "Invalid input: YYYY (year) has to be number."	
	if ((MM<0) || (MM>11) || isNaN( MM ))			return "Invalid input: MM (month) must be a number in the range 1-12.";
	if ((DD<1) || (DD>31) || isNaN( DD ))			return "Invalid input: DD (date) must be a number in the range 1-31.";
	if ((Hours<0) || (Hours>23) || isNaN( Hours ))		return "Invalid input: Hours must be a number in the range 0-23.";
	if ((Minutes<0) || (Minutes>59) || isNaN( Minutes ))	return "Invalid input: Minutes must be a number in the range 0-59.";
	if ((Seconds<0) || (Seconds>59) || isNaN( Seconds ))	return "Invalid input: Seconds must be a number in the range 0-59.";

	var NumDiff = GetExactDifference( YYYY , MM, DD, Hours, Minutes, Seconds);
	var CalDiff = GetCalendarDateDifference( YYYY , MM , DD );

	if ((OutputFormat == null) || (OutputFormat == ""))
		OutputFormat = "<Weeks> weeks, <Days> days, <Hours> hours, <Minutes> minutes, <Seconds> seconds";

	OutputFormat = OutputFormat.replace( /<NumDiff>/gi	, NumDiff ); //For troubleshooting
	OutputFormat = OutputFormat.replace( /<CalDiff>/gi	, CalDiff ); //For troubleshooting

	OutputFormat = OutputFormat.replace( /<DownOrUp>/gi	, NumDiff[0] );
	OutputFormat = OutputFormat.replace( /<Weeks>/gi	, NumDiff[1] );
	OutputFormat = OutputFormat.replace( /<Days>/gi		, NumDiff[2] );
	OutputFormat = OutputFormat.replace( /<DaysTotal>/gi	, NumDiff[3] );
	OutputFormat = OutputFormat.replace( /<Hours>/gi 	, NumDiff[4] );
	OutputFormat = OutputFormat.replace( /<Minutes>/gi	, NumDiff[5] );
	OutputFormat = OutputFormat.replace( /<Seconds>/gi	, NumDiff[6] );
	
	OutputFormat = OutputFormat.replace( /<CalDownOrUp>/gi	, CalDiff[0] );
	OutputFormat = OutputFormat.replace( /<CalYears>/gi	, CalDiff[1] );
	OutputFormat = OutputFormat.replace( /<CalMonths>/gi	, CalDiff[2] );
	OutputFormat = OutputFormat.replace( /<CalDays>/gi	, CalDiff[3] );

	return OutputFormat;

	function GetExactDifference( iYYYY, iMM, iDD, iHours, iMinutes, iSeconds ) {

		var Diff, CountingDown, NumWeeks, NumDays, NumDaysTotal, NumHours, NumMinutes, NumSeconds;

		Diff		= GetDifferenceInMilliseconds( iYYYY , iMM , iDD , iHours, iMinutes , iSeconds );

		CountingDown	= ( Diff < 0 ) ? CountingDownText : CountingUpText;
		Diff		= Math.abs( Diff );

		NumWeeks	= Math.floor(Diff / iOneWeek);
		NumDays		= Math.floor( (Diff % iOneWeek) / iOneDay);

		NumDaysTotal	= Math.floor(Diff / iOneDay);
		Diff		= Diff % iOneDay;

		NumHours	= Math.floor(Diff / iOneHour);
		Diff		= Diff % iOneHour;

		NumMinutes	= Math.floor(Diff / iOneMinute);
		Diff		= Diff % iOneMinute;

		NumSeconds	= Math.floor(Diff / iOneSecond);

		return new Array( CountingDown, NumWeeks, NumDays, NumDaysTotal, NumHours, NumMinutes, NumSeconds);
 
			function GetDifferenceInMilliseconds( iYYYY, iMM, iDD, iHrs, iMin, iSec ){
			// Gets the number of milliseconds between the current time and the target time.
			// Negative values means that the target time is in the future.

				var dTarget, tNow, tTarget, tDiff;

				tNow = new Date().getTime();

				dTarget = new Date();
				dTarget.setHours( 0 ,0 ,0 ,1 );		// Just in case the current "seconds" value is near 59.999
				dTarget.setFullYear( iYYYY, iMM, iDD);	// Setting the date, using the local timezone
				dTarget.setHours( iHrs, iMin, iSec, 0);	// Setting the time, using the local timezone

				tTarget = Date.UTC(	dTarget.getUTCFullYear(),
							dTarget.getUTCMonth(),
							dTarget.getUTCDate(),
							dTarget.getUTCHours(),
							dTarget.getUTCMinutes(),
							dTarget.getUTCSeconds()
					);
				//tDiff = (tNow >= tTarget) ? tNow - tTarget : tTarget - tNow;
				tDiff = tNow - tTarget;

				return tDiff;
			}

		
		}

	function GetCalendarDateDifference( iYYYY, iMM , iDD ) {

		var dLow, dHigh, dIterate, iYearDiff, iMonthDiff, iDateDiff, strUD;

		var dTarget = new Date();
		dTarget.setHours( 0 ,0 ,0 ,1 );
		dTarget.setFullYear( iYYYY, iMM, iDD);

		var dNow = new Date();
		dNow.setHours( 0 ,0 ,0 ,1 );

		if (dNow < dTarget) {
			dLow	= new Date(dNow);
			dHigh	= new Date(dTarget);
			strUD	= CountingDownText;

		} else {
			dLow	= new Date(dTarget);
			dHigh	= new Date(dNow);
			strUD	= CountingUpText;
		}

		iYearDiff	= dHigh.getFullYear() - dLow.getFullYear();
		dIterate	= new Date(dLow);
		dIterate.setFullYear( dLow.getFullYear() + iYearDiff );
		if (dIterate > dHigh) iYearDiff--;		

		iMonthDiff	= 0;
		dIterate	= new Date(dLow);
		dIterate.setFullYear( dIterate.getFullYear() + iYearDiff );
		
		for (i = 0 ; i <= 12; i++) {
			dIterate.setMonth( dLow.getMonth() + i );
			if (dIterate <= dHigh) iMonthDiff = i;
		}

		iDateDiff	= 0;
		dIterate	= new Date(dLow);
		dIterate.setFullYear( dIterate.getFullYear() + iYearDiff );
		dIterate.setMonth( dIterate.getMonth() + iMonthDiff );

		for (i = 0; i <=31 ; i++) {
			dIterate.setMonth( dLow.getMonth() + iMonthDiff ,  dLow.getDate() + i);
			if (dIterate <= dHigh) iDateDiff = i;
		}

		return new Array( strUD, iYearDiff , iMonthDiff , iDateDiff, dLow, dHigh, dIterate );
	}

}

function ShowOutputFormatTags() {
	var result = 	"These \"OutputFormat\"-tags are understood by CountDownOrUp:\r\n";
	result +=	"<DownOrUp> <Weeks> <Days> <DaysTotal> <Hours> <Minutes> <Seconds>\r\n";
	result +=	"<CalDownOrUp> <CalYears> <CalMonths> <CalDays>";

	return result;
}